@@ -63,25 +63,6 @@
 #define GCM_PREFS_PACKAGE_NAME_COLOR_PROFILES		"shared-color-profiles"
 #define GCM_PREFS_PACKAGE_NAME_COLOR_PROFILES_EXTRA	"shared-color-profiles-extra"
 
-/* libnotify dummy code */
-#ifndef HAVE_NOTIFY
-#define	notify_init(f1)						/* nothing */
-#define	notify_is_initted(f1)					FALSE
-#define	notify_notification_close(f1,f2)			TRUE
-#define	notify_notification_show(f1,f2)				TRUE
-#define	notify_notification_set_timeout(f1,f2)			/* nothing */
-#define	notify_notification_set_urgency(f1,f2)			/* nothing */
-#define	notify_notification_add_action(f1,f2,f3,f4,f5,f6)	/* nothing */
-#define NotifyNotification					GtkWidget
-#define	NotifyUrgency						guint
-#define	notify_notification_new(f1,f2,f3,f4)			gtk_fixed_new()
-#define	notify_notification_new_with_status_icon(f1,f2,f3,f4)	gtk_fixed_new()
-#define NOTIFY_URGENCY_LOW					0
-#define NOTIFY_URGENCY_NORMAL					1
-#define NOTIFY_URGENCY_CRITICAL					2
-#define NOTIFY_EXPIRES_NEVER					0
-#endif
-
 gboolean	 gcm_utils_mkdir_for_filename		(const gchar		*filename,
 							 GError			**error);
 gboolean	 gcm_utils_mkdir_and_copy		(GFile			*source,
@@ -98,7 +79,6 @@ gchar		*gcm_utils_get_default_config_location	(void);
 GcmProfileKind	 gcm_utils_device_kind_to_profile_kind	(GcmDeviceKind		 kind);
 gboolean	 gcm_utils_install_package		(const gchar		*package_name,
 							 GtkWindow		*window);
-gboolean	 gcm_utils_is_package_installed		(const gchar		*package_name);
 gboolean	 gcm_utils_is_icc_profile		(GFile			*file);
 gchar		*gcm_utils_linkify			(const gchar		*text);
 const gchar	*gcm_intent_to_localized_text		(GcmIntent	 intent);
